==> nui_web-0.0.4.tar.gz: lib/nui_connection.dart <==
import 'dart:async';
import 'dart:io';
import 'package:connectivity/connectivity.dart';
import 'package:nui_core/code/nui_code_util.dart';

typedef ConnectivityChangeListener = void Function(ConnectivityResult result, bool hasInternet);

class NUIConnectionUtil{
  static const _MODULE = "NUIWeb";
  static const CONNECTIVITY_CHANNEL = "NUIConnectivityChannel";
  NUIConnectionUtil._builder();

  static Future<bool> hasConnection({String lookUpUrl: "google.com"}) async{
    final targetUrl = lookUpUrl ?? "google.com";
    final connectivity = await checkConnectivity();
    if(connectivity == ConnectivityResult.none){
      //There is no network found, so there will not be any network connection
      return false;
    }

    //Device is connected to either a mobile network or a wifi network, re-confirm network connection by connecting to target url
    try {
      final result = await InternetAddress.lookup(targetUrl);
      if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
        return true;
      }
    } on SocketException catch (e) {
      logNUI(_MODULE, "Failed to connect to $targetUrl with error : $e");
    }
    return false;
  }

  static StreamSubscription<ConnectivityResult> subscribeConnectivityChange(ConnectivityChangeListener listener){
    final subscription = Connectivity().onConnectivityChanged.listen((ConnectivityResult result) async {
      if(listener != null){
        final bool hasInternet = await hasConnection();
        listener(result, hasInternet);
      }
    });
    return subscription;
  }

  static Future<ConnectivityResult> checkConnectivity() async{
    var connectivityResult = await (Connectivity().checkConnectivity());
    if (connectivityResult == ConnectivityResult.mobile) {
      // I am connected to a mobile network.
      logNUI(_MODULE, "Device is connected to a mobile network");
    } else if (connectivityResult == ConnectivityResult.wifi) {
      // I am connected to a wifi network.
      logNUI(_MODULE, "Device is connected to a wifi network");
    } else {
      // No connectivity
      logNUI(_MODULE, "Device is not connected to any network");
    }
    return connectivityResult;
  }

}

==> nui_web-0.0.24.tar.gz: lib/nui_connection.dart <==
import 'dart:async';
import 'dart:io';
import 'package:connectivity/connectivity.dart';
import 'package:nui_core/code/nui_code_util.dart';

typedef ConnectivityChangeListener = void Function(ConnectivityResult result, bool hasInternet);

class NUIConnectionUtil{
  static const _MODULE = "NUIWeb";
  static const CONNECTIVITY_CHANNEL = "NUIConnectivityChannel";
  NUIConnectionUtil._builder();

  static Future<bool> hasConnection({String lookUpUrl: "google.com", bool lookUp: false}) async{
    final targetUrl = lookUpUrl ?? "google.com";
    final connectivity = await checkConnectivity();
    if(connectivity == ConnectivityResult.none){
      //There is no network found, so there will not be any network connection
      return false;
    }

    //Device is connected to either a mobile network or a wifi network, re-confirm network connection by connecting to target url
    try {
      if(lookUp == true) {
        final result = await InternetAddress.lookup(targetUrl);
        if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
          return true;
        }
      }
      else {
        return true;
      }
    } on SocketException catch (e) {
      logNUI(_MODULE, "Failed to connect to $targetUrl with error : $e");
    }
    return false;
  }

  static StreamSubscription<ConnectivityResult> subscribeConnectivityChange(ConnectivityChangeListener listener){
    final subscription = Connectivity().onConnectivityChanged.listen((ConnectivityResult result) async {
      if(listener != null){
        final bool hasInternet = await hasConnection();
        listener(result, hasInternet);
      }
    });
    return subscription;
  }

  static Future<ConnectivityResult> checkConnectivity() async{
    var connectivityResult = await (Connectivity().checkConnectivity());
    if (connectivityResult == ConnectivityResult.mobile) {
      // I am connected to a mobile network.
      logNUI(_MODULE, "Device is connected to a mobile network");
    } else if (connectivityResult == ConnectivityResult.wifi) {
      // I am connected to a wifi network.
      logNUI(_MODULE, "Device is connected to a wifi network");
    } else {
      // No connectivity
      logNUI(_MODULE, "Device is not connected to any network");
    }
    return connectivityResult;
  }

}
